<?php 
/*
Plugin Name: TNG Embed Widget Plugin
Plugin URI: http://jontang.se/tng-embed-widget-plugin
Description: A plugin for embeding stuff in the sidebar. Using oEmbed. Supporting all WordPress embed services.
Version: 1.0
Author: Jon Täng
Author URI: http://jontang.se
License: GPL2
*/

load_plugin_textdomain('tng_embed_widget', false, basename( dirname( __FILE__ ) ) . '/languages' );
// register Foo_Widget widget
add_action( 'widgets_init', create_function( '', 'register_widget( "tng_embed_widget" );' ) );

/**
 * Adds Foo_Widget widget.
 */
class TNG_Embed_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function TNG_Embed_Widget() {
		$widget_ops = array( 
			'classname' => 'tng_embed_widget', 
			'description' => __( 'A Widget for embedding stuff. Using oEmbed. Supporting all WordPress embed formats', 'tng_embed_widget' ) );
		$this->WP_Widget( 'tng_embed_widget', __( 'TNG Embed Widget', 'tng_embed_widget' ), $widget_ops );
		$this->alt_option_name = 'tng_embed_widget';
	}

	/**
	 * Front-end display of widget.
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );
		
		if ( !isset($url) )
			return;
		
		$embed_args = array(
			'width' => (int)$width,
			'height' => (int)($width * $ratio)
		);
				
		echo $before_widget;
		if ( ! empty( $title ) ) echo $before_title . $title . $after_title;
		echo '<div class="widget-content">', wp_oembed_get( $url, $embed_args ), '</div>';
		echo $after_widget;
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['url'] = strip_tags( $new_instance['url'] );
		$instance['width'] = strip_tags( $new_instance['width'] );
		$instance['ratio'] = strip_tags( $new_instance['ratio'] );

		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @param array $instance Previously saved values from database.
	 */
	function form( $instance ) {
		$title = isset( $instance['title']) ? esc_attr( $instance['title'] ) : __('Something', 'tng_embed_widget');
		$url = isset( $instance['url']) ? esc_url( $instance['url'] ) : '';
		$width = isset( $instance['width']) ? (int)( $instance['width'] ) : 370;
		$ratio = isset( $instance['ratio']) ? (float)( $instance['ratio'] ) : (3/4);
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Widget title:', 'tng_embed_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php _e( 'Embed URL:', 'tng_embed_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" type="text" value="<?php echo esc_attr( $url ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>"><?php _e( 'Width:', 'tng_embed_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'width' ); ?>" name="<?php echo $this->get_field_name( 'width' ); ?>" type="text" value="<?php echo esc_attr( $width ); ?>" />
		</p>
		<p>
			<?php $ratios = array( '4:3' => (3/4), '16:10' => (10/16), '16:9' => (9/16) ); ?>
			<label for="<?php echo $this->get_field_id( 'ratio' ); ?>"><?php _e( 'Ratio:', 'tng_embed_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'ratio' ); ?>" name="<?php echo $this->get_field_name( 'ratio' ); ?>">
			<?php foreach ( $ratios as $l => $v ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $ratio, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		<?php 
	}

} // class Foo_Widget